package org.framework.lazy.cloud.network.heartbeat.common.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpClientProxyClientTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpClientProxyServerTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpLocalProxyTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.client.*;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.server.*;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.socks.AbstractHandleSocketLocalProxyTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.socks.client.*;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.socks.server.*;
import org.framework.lazy.cloud.network.heartbeat.common.constant.ProxyMessageType;
import org.framework.lazy.cloud.network.heartbeat.common.constant.TcpMessageType;

/**
 * @see TcpMessageType
 */
@Getter
@AllArgsConstructor
public enum ProxyMessageTypeEnums {

    /**
     * http本地代理
     *
     * @see AbstractHttpLocalProxyTypeAdvanced
     */
    HTTP_LOCAL_PROXY(ProxyMessageType.HTTP_LOCAL_PROXY, "http本地代理"),

    /**
     * http 远程客户端代理
     *
     * @see AbstractHttpClientProxyClientTypeAdvanced
     */
    HTTP_CLIENT_PROXY_CLIENT_(ProxyMessageType.HTTP_CLIENT_PROXY_CLIENT_, "http远程客户端代理"),
    /**
     * http 远程服务端代理
     * @see AbstractHttpClientProxyServerTypeAdvanced
     */
    HTTP_CLIENT_PROXY_SERVER_(ProxyMessageType.HTTP_CLIENT_PROXY_SERVER_, "http远程服务端代理"),
    /**
     * http 远程服务端代理传输数据上报
     * @see AbstractHandleHttpReportClientProxyServerTransferTypeAdvanced
     */
    HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_(ProxyMessageType.HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_, "http远程服务端代理传输数据上报"),
    /**
     * http 远程服务端代理传输数据下发
     * @see AbstractHandleHttpDistributeClientProxyServerTransferTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_, "http远程服务端代理传输数据下发"),
    /**
     * http 远程代理服务通道关闭
     * @see AbstractHandleHttpReportClientProxyServerTransferCloseTypeAdvanced
     */
    HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_(ProxyMessageType.HTTP_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_, "http远程服务端代理传输数据下发"),
    /**
     * http 下发服务端路由
     * @see AbstractHandleHttpDistributeClientProxyServerServerRouteTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_, "http下发服务端路由"),
    /**
     * 下发服务端路由关闭
     *
     * @see ProxyMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_CLOSE_
     * @see AbstractHandleHttpDistributeClientProxyServerServerRouteCloseTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_CLOSE_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_SERVER_ROUTE_CLOSE_, "下发服务端路由关闭"),
    /**
     * http 下发客户端路由
     *
     * @see AbstractHandleHttpDistributeClientProxyServerClientRouteTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_, "http下发客户端路由"),
    /**
     * 下发客户端路由关闭
     *
     * @see ProxyMessageTypeEnums#HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_CLOSE_
     * @see AbstractHandleHttpDistributeClientProxyServerClientRouteCloseTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_CLOSE_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_SERVER_CLIENT_ROUTE_CLOSE_, "下发客户端路由关闭"),
    /**
     * http 客户端远程客户端代理传输连接
     *
     * @see AbstractHandleHttpReportClientProxyClientConnectionTransferTypeAdvanced
     */
    HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_(ProxyMessageType.HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_, "http 客户端远程客户端代理传输连接"),

    /**
     * http  客户端代理客户端，客户端连接服务端成功
     *
     * @see AbstractHandleHttpDistributeClientProxyClientConnectionTransferSuccessfulTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESSFUL_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESSFUL_, "http 客户端代理客户端，客户端连接服务端成功"),
    /**
     * http 目标客户端传输通道连接初始化成功
     *
     * @see AbstractHandleHttpReportClientProxyClientTransferChannelInitSuccessfulTypeAdvanced
     */
    HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_(ProxyMessageType.HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_, "http 目标客户端传输通道连接初始化成功"),
    /**
     * http 下发数据到另一个客户端
     *
     * @see AbstractHandleHttpDistributeClientProxyClientTransferRequestTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_, "http 下发数据到另一个客户端"),
    /**
     * http 另一个客户端将返回数据通过传输通道返回
     *
     * @see AbstractHandleHttpReportClientProxyClientTransferResponseTypeAdvanced
     */
    HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_(ProxyMessageType.HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_, "http 另一个客户端将返回数据通过传输通道返回"),
    /**
     * 下发返回结果
     *
     * @see AbstractHandleHttpDistributeClientProxyClientTransferResponseTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_, "http 下发返回结果"),

    /**
     * 上报传输通道关闭
     *
     * @see AbstractHandleHttpReportClientProxyClientTransferCloseTypeAdvanced
     */
    HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.HTTP_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_, "http 上报传输通道关闭"),
    /**
     * 下发传输通道关闭
     * @see AbstractHandleHttpDistributeClientProxyClientTransferCLoseTypeAdvanced
     */
    HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.HTTP_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_, "http 下发传输通道关闭"),
    /**
     * 服务端代理客户端
     * @see AbstractHttpServerProxyClientTypeAdvanced
     */
    HTTP_SERVER_PROXY_CLIENT_(ProxyMessageType.HTTP_SERVER_PROXY_CLIENT_, "http 服务端代理客户端"),
    /**
     * http 下发服务端连接客户端
     *
     * @see AbstractHandleHttpDistributeServerProxyClientConnectionSuccessfulTypeAdvanced
     */
    HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_SUCCESSFUL_(ProxyMessageType.HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_SUCCESSFUL_, "http 下发服务端连接客户端"),
    /**
     * http 上报客户端连接成功
     *
     * @see ProxyMessageType#HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_
     * @see AbstractHandleHttpReportServerProxyClientTransferChannelInitSuccessfulTypeAdvanced
     */
    HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_(ProxyMessageType.HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CHANNEL_INIT_SUCCESSFUL_, "http 上报客户端连接成功"),
    /**
     * 下发数据到另一个客户端
     *  @see AbstractHandleHttpDistributeServerProxyClientTransferRequestTypeAdvanced
     */
    HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_(ProxyMessageType.HTTP_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_, "http 下发数据到另一个客户端"),

    /**
     * 下发返回结果
     *  @see AbstractHandleHttpReportServerProxyClientTransferResponseTypeAdvanced
     */
    HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_(ProxyMessageType.HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_, "http 下发返回结果"),

    /**
     * 上报传输通道关闭
     *  @see AbstractHandleHttpReportServerProxyClientTransferCloseTypeAdvanced
     */
    HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.HTTP_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_, "http 上报传输通道关闭"),


    /**
     * socket本地代理
     *  @see AbstractHandleSocketLocalProxyTypeAdvanced
     */
    SOCKS_LOCAL_PROXY(ProxyMessageType.SOCKS_LOCAL_PROXY, "socket本地代理"),
    /**
     * socket 客户端代理客户端
     *
     * @see ProxyMessageTypeEnums#SOCKS_CLIENT_PROXY_CLIENT_
     * @see AbstractHandleSocketClientProxyClientStartTypeAdvanced
     */
    SOCKS_CLIENT_PROXY_CLIENT_(ProxyMessageType.SOCKS_CLIENT_PROXY_CLIENT_, "socket 客户端代理客户端"),
    /**
     * socket 客户端代理服务端
     *
     * @see ProxyMessageTypeEnums#SOCKS_CLIENT_PROXY_SERVER_
     * @see AbstractHandleSocketClientProxyServerStartTypeAdvanced
     */
    SOCKS_CLIENT_PROXY_SERVER_(ProxyMessageType.SOCKS_CLIENT_PROXY_SERVER_, "socket 客户端代理服务端"),

    /**
     * socket 上报客户端代理服务端传输通道连接成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_
     * @see AbstractHandleSocksReportClientProxyServerConnectionTransferTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_, "socket 上报客户端代理服务端传输通道连接成功"),
    /**
     * socket 下发客户端代理服务端传输通道连接成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_SUCCESS_
     * @see AbstractHandleSocksDistributeClientProxyServerConnectionTransferSuccessTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_SUCCESS_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_SUCCESS_, "socket 下发客户端代理服务端传输通道连接成功"),

    /**
     * socket 下发客户端代理服务端传输通道连接失败
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_FAIL_
     * @see AbstractHandleSocksDistributeClientProxyServerConnectionTransferFailTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_FAIL_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CONNECTION_FAIL_, "socket 下发客户端代理服务端传输通道连接成功"),

    /**
     * socket 上报客户端代理服务端请求
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_REQUEST_
     * @see AbstractHandleSocksReportClientProxyServerTransferRequestTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_REQUEST_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_REQUEST_, "socket 上报客户端代理服务端请求"),
    /**
     * socket 下发客户端代理服务端数据返回
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_RESPONSE_
     * @see AbstractHandleSocksDistributeClientProxyServerTransferResponseTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_RESPONSE_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_RESPONSE_, "socket 下发客户端代理服务端数据返回"),
    /**
     * socket 上报客户端代理服务端传输通道关闭
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_
     * @see AbstractHandleSocksReportClientProxyServerTransferCloseTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_, "socket 上报客户端代理服务端传输通道关闭"),
    /**
     * socket 下发客户端代理服务端传输通道关闭
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_
     * @see AbstractHandleSocksDistributeClientProxyServerTransferCloseTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_SERVER_TRANSFER_CLOSE_, "socket 下发客户端代理服务端传输通道关闭"),
    /**
     * socket 上报客户端代理客户端传输通道连接成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_
     * @see AbstractHandleSocksReportClientProxyClientConnectionTransferTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_, "socket 上报客户端代理客户端传输通道连接成功"),
    /**
     * socket 下发客户端代理客户端传输通道连接成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_OTHER_TRANSFER_CONNECTION_
     * @see AbstractHandleSocksDistributeClientProxyClientOtherConnectionTransferTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_OTHER_TRANSFER_CONNECTION_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_OTHER_TRANSFER_CONNECTION_, "socket 上报客户端代理客户端传输通道连接成功"),
    /**
     * socket 上报客户端代理客户端传输通道连接成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_CLIENT_OTHER_TRANSFER_CONNECTION_SUCCESS_
     * @see AbstractHandleSocksReportClientProxyClientOtherConnectionTransferSuccessTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_CLIENT_OTHER_TRANSFER_CONNECTION_SUCCESS_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_CLIENT_OTHER_TRANSFER_CONNECTION_SUCCESS_, "socket 上报客户端代理客户端传输通道连接成功"),

    /**
     * socket 下发客户端代理客户端传输通道连接成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESS_
     * @see AbstractHandleSocksDistributeClientProxyClientConnectionTransferSuccessTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESS_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_SUCCESS_, "socket 下发客户端代理客户端传输通道连接成功"),
    /**
     * socket 下发客户端代理客户端传输通道连接失败
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_FAIL_
     * @see AbstractHandleSocksDistributeClientProxyClientConnectionTransferSuccessTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_FAIL_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CONNECTION_FAIL_, "socket 下发客户端代理客户端传输通道连接失败"),

    /**
     * socket 上报客户端代理客户端请求
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_
     * @see AbstractHandleSocksReportClientProxyClientTransferRequestTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_, "socket 上报客户端代理客户端请求"),
    /**
     * socket 下发客户端代理客户端请求
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_
     * @see AbstractHandleSocksDistributeClientProxyClientTransferRequestTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_REQUEST_, "socket 下发客户端代理客户端请求"),
    /**
     * socket 上报客户端代理客户端数据返回
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_
     * @see AbstractHandleSocksReportClientProxyClientTransferResponseTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_, "socket 上报客户端代理客户端数据返回"),
    /**
     * socket 下发客户端代理客户端数据返回
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_
     * @see AbstractHandleSocksDistributeClientProxyClientTransferResponseTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_RESPONSE_, "socket 下发客户端代理客户端数据返回"),
    /**
     * socket 上报客户端代理客户端传输通道关闭
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleSocksReportClientProxyClientTransferCloseTypeAdvanced
     */
    SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.SOCKS_REPORT_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_, "socket 上报客户端代理客户端传输通道关闭"),
    /**
     * socket 下发客户端代理客户端传输通道关闭
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleSocksDistributeClientProxyClientTransferCloseTypeAdvanced
     */
    SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.SOCKS_DISTRIBUTE_CLIENT_PROXY_CLIENT_TRANSFER_CLOSE_, "socket 下发客户端代理客户端传输通道关闭"),


    /**
     * socket 服务端代理客户端
     *
     * @see ProxyMessageTypeEnums#SOCKS_SERVER_PROXY_CLIENT_
     * @see AbstractHandleSocksReportServerProxyClientTypeAdvanced
     */
    SOCKS_SERVER_PROXY_CLIENT_(ProxyMessageType.SOCKS_SERVER_PROXY_CLIENT_, "socket 服务端代理客户端"),
    /**
     * socket 下发客户端代理服务端连接初始化
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_INIT_
     * @see AbstractHandleSocksDistributeServerProxyClientConnectionInitTypeAdvanced
     */
    SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_INIT_(ProxyMessageType.SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_CONNECTION_INIT_, "socket 下发客户端代理服务端连接初始化"),
    /**
     * socket 上报客户端代理服务端连接初始化成功
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_SERVER_PROXY_CLIENT_CONNECTION_SUCCESS_
     * @see AbstractHandleSocksReportServerProxyClientConnectionSuccessTypeAdvanced
     */
    SOCKS_REPORT_SERVER_PROXY_CLIENT_CONNECTION_SUCCESS_(ProxyMessageType.SOCKS_REPORT_SERVER_PROXY_CLIENT_CONNECTION_SUCCESS_, "socket 上报客户端代理服务端连接初始化成功"),
    /**
     * socket 下发客户端代理服务端 请求数据
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_
     * @see AbstractHandleSocksDistributeServerProxyClientRequestTypeAdvanced
     */
    SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_(ProxyMessageType.SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_REQUEST_, "socket 下发客户端代理服务端 请求数据"),
    /**
     * socket 上报客户端代理服务端 结果返回
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_
     * @see AbstractHandleSocksReportServerProxyClientResponseTypeAdvanced
     */
    SOCKS_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_(ProxyMessageType.SOCKS_REPORT_SERVER_PROXY_CLIENT_TRANSFER_RESPONSE_, "socket 上报客户端代理服务端 结果返回"),
    /**
     * socket 下发客户端代理服务端 传输通道关闭
     *
     * @see ProxyMessageTypeEnums#SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleSocksDistributeServerProxyClientTransferCloseAdvanced
     */
    SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.SOCKS_DISTRIBUTE_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_, "socket 下发客户端代理服务端 传输通道关闭"),
    /**
     * socket 上报客户端代理服务端 传输通道关闭
     *
     * @see ProxyMessageTypeEnums#SOCKS_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_
     * @see AbstractHandleSocksReportServerProxyClientTransferCloseTypeAdvanced
     */
    SOCKS_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_(ProxyMessageType.SOCKS_REPORT_SERVER_PROXY_CLIENT_TRANSFER_CLOSE_, "socket 上报客户端代理服务端 传输通道关闭"),


    ;

    private final byte typeByte;
    private final String desc;

}
