package org.framework.lazy.cloud.network.heartbeat.server.standalone.application.impl;

import org.wu.framework.database.lazy.web.plus.stereotype.LazyApplication;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.LazyNettyServerVirtualRouteApplication;
import org.springframework.web.bind.annotation.*;
import org.wu.framework.web.response.Result;
import org.wu.framework.web.response.ResultFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.server.virtual.route.LazyNettyServerVirtualRoute;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteRemoveCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteStoryCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteUpdateCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteQueryListCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteQueryOneCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.assembler.LazyNettyServerVirtualRouteDTOAssembler;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.dto.LazyNettyServerVirtualRouteDTO;
import java.util.stream.Collectors;
import jakarta.annotation.Resource;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteRepository;
import java.util.List;
import org.wu.framework.lazy.orm.database.lambda.domain.LazyPage;
/**
 * describe 服务端虚拟路由管理 
 *
 * @author Jia wei Wu
 * @date 2025/05/06 05:00 下午
 * @see org.wu.framework.lazy.orm.core.persistence.reverse.lazy.ddd.DefaultDDDLazyApplicationImpl 
 **/
@LazyApplication
public class LazyNettyServerVirtualRouteApplicationImpl implements LazyNettyServerVirtualRouteApplication {

    @Resource
    LazyNettyServerVirtualRouteRepository lazyNettyServerVirtualRouteRepository;
    /**
     * describe 新增服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteStoryCommand 新增服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRoute>} 服务端虚拟路由管理新增后领域对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<LazyNettyServerVirtualRoute> story(LazyNettyServerVirtualRouteStoryCommand lazyNettyServerVirtualRouteStoryCommand) {
        LazyNettyServerVirtualRoute lazyNettyServerVirtualRoute = LazyNettyServerVirtualRouteDTOAssembler.INSTANCE.toLazyNettyServerVirtualRoute(lazyNettyServerVirtualRouteStoryCommand);
        return lazyNettyServerVirtualRouteRepository.story(lazyNettyServerVirtualRoute);
    }
    /**
     * describe 批量新增服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteStoryCommandList 批量新增服务端虚拟路由管理     
     * @return {@link Result<List<LazyNettyServerVirtualRoute>>} 服务端虚拟路由管理新增后领域对象集合     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<List<LazyNettyServerVirtualRoute>> batchStory(List<LazyNettyServerVirtualRouteStoryCommand> lazyNettyServerVirtualRouteStoryCommandList) {
        List<LazyNettyServerVirtualRoute> lazyNettyServerVirtualRouteList = lazyNettyServerVirtualRouteStoryCommandList.stream().map( LazyNettyServerVirtualRouteDTOAssembler.INSTANCE::toLazyNettyServerVirtualRoute).collect(Collectors.toList());
        return lazyNettyServerVirtualRouteRepository.batchStory(lazyNettyServerVirtualRouteList);
    }
    /**
     * describe 更新服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteUpdateCommand 更新服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRoute>} 服务端虚拟路由管理领域对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<LazyNettyServerVirtualRoute> updateOne(LazyNettyServerVirtualRouteUpdateCommand lazyNettyServerVirtualRouteUpdateCommand) {
        LazyNettyServerVirtualRoute lazyNettyServerVirtualRoute = LazyNettyServerVirtualRouteDTOAssembler.INSTANCE.toLazyNettyServerVirtualRoute(lazyNettyServerVirtualRouteUpdateCommand);
        return lazyNettyServerVirtualRouteRepository.story(lazyNettyServerVirtualRoute);
    }

    /**
     * describe 查询单个服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteQueryOneCommand 查询单个服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRouteDTO>} 服务端虚拟路由管理DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<LazyNettyServerVirtualRouteDTO> findOne(LazyNettyServerVirtualRouteQueryOneCommand lazyNettyServerVirtualRouteQueryOneCommand) {
        LazyNettyServerVirtualRoute lazyNettyServerVirtualRoute = LazyNettyServerVirtualRouteDTOAssembler.INSTANCE.toLazyNettyServerVirtualRoute(lazyNettyServerVirtualRouteQueryOneCommand);
        return lazyNettyServerVirtualRouteRepository.findOne(lazyNettyServerVirtualRoute).convert(LazyNettyServerVirtualRouteDTOAssembler.INSTANCE::fromLazyNettyServerVirtualRoute);
    }

    /**
     * describe 查询多个服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteQueryListCommand 查询多个服务端虚拟路由管理     
     * @return {@link Result<List<LazyNettyServerVirtualRouteDTO>>} 服务端虚拟路由管理DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<List<LazyNettyServerVirtualRouteDTO>> findList(LazyNettyServerVirtualRouteQueryListCommand lazyNettyServerVirtualRouteQueryListCommand) {
        LazyNettyServerVirtualRoute lazyNettyServerVirtualRoute = LazyNettyServerVirtualRouteDTOAssembler.INSTANCE.toLazyNettyServerVirtualRoute(lazyNettyServerVirtualRouteQueryListCommand);
        return lazyNettyServerVirtualRouteRepository.findList(lazyNettyServerVirtualRoute)        .convert(lazyNettyServerVirtualRoutes -> lazyNettyServerVirtualRoutes.stream().map(LazyNettyServerVirtualRouteDTOAssembler.INSTANCE::fromLazyNettyServerVirtualRoute).collect(Collectors.toList())) ;
    }

    /**
     * describe 分页查询多个服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteQueryListCommand 分页查询多个服务端虚拟路由管理     
     * @return {@link Result<LazyPage<LazyNettyServerVirtualRouteDTO>>} 分页服务端虚拟路由管理DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<LazyPage<LazyNettyServerVirtualRouteDTO>> findPage(int size,int current,LazyNettyServerVirtualRouteQueryListCommand lazyNettyServerVirtualRouteQueryListCommand) {
        LazyNettyServerVirtualRoute lazyNettyServerVirtualRoute = LazyNettyServerVirtualRouteDTOAssembler.INSTANCE.toLazyNettyServerVirtualRoute(lazyNettyServerVirtualRouteQueryListCommand);
        return lazyNettyServerVirtualRouteRepository.findPage(size,current,lazyNettyServerVirtualRoute)        .convert(page -> page.convert(LazyNettyServerVirtualRouteDTOAssembler.INSTANCE::fromLazyNettyServerVirtualRoute))            ;
    }

    /**
     * describe 删除服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteRemoveCommand 删除服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRoute>} 服务端虚拟路由管理     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Override
    public Result<LazyNettyServerVirtualRoute> remove(LazyNettyServerVirtualRouteRemoveCommand lazyNettyServerVirtualRouteRemoveCommand) {
     LazyNettyServerVirtualRoute lazyNettyServerVirtualRoute = LazyNettyServerVirtualRouteDTOAssembler.INSTANCE.toLazyNettyServerVirtualRoute(lazyNettyServerVirtualRouteRemoveCommand);
     return lazyNettyServerVirtualRouteRepository.remove(lazyNettyServerVirtualRoute);
    }

}