package org.framework.lazy.cloud.network.heartbeat.server.standalone.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import org.wu.framework.web.spring.EasyController;
import org.springframework.web.bind.annotation.*;
import org.wu.framework.web.response.Result;
import org.wu.framework.web.response.ResultFactory;
import org.springframework.beans.factory.annotation.Autowired;
import jakarta.annotation.Resource;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.lazy.netty.server.virtual.route.LazyNettyServerVirtualRoute;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteRemoveCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteStoryCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteUpdateCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteQueryListCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.command.lazy.netty.server.virtual.route.LazyNettyServerVirtualRouteQueryOneCommand;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.LazyNettyServerVirtualRouteApplication;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.dto.LazyNettyServerVirtualRouteDTO;
import java.util.List;
import org.wu.framework.lazy.orm.database.lambda.domain.LazyPage;
/**
 * describe 服务端虚拟路由管理 
 *
 * @author Jia wei Wu
 * @date 2025/05/06 05:00 下午
 * @see org.wu.framework.lazy.orm.core.persistence.reverse.lazy.ddd.DefaultDDDLazyController 
 **/
@Tag(name = "服务端虚拟路由管理提供者")
@EasyController("/lazy/netty/server/virtual/route")
public class LazyNettyServerVirtualRouteProvider  {

    @Resource
    private LazyNettyServerVirtualRouteApplication lazyNettyServerVirtualRouteApplication;

    /**
     * describe 新增服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteStoryCommand 新增服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRoute>} 服务端虚拟路由管理新增后领域对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "新增服务端虚拟路由管理")
    @PostMapping("/story")
    public Result<LazyNettyServerVirtualRoute> story(@RequestBody LazyNettyServerVirtualRouteStoryCommand lazyNettyServerVirtualRouteStoryCommand){
        return lazyNettyServerVirtualRouteApplication.story(lazyNettyServerVirtualRouteStoryCommand);
    }
    /**
     * describe 批量新增服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteStoryCommandList 批量新增服务端虚拟路由管理     
     * @return {@link Result<List<LazyNettyServerVirtualRoute>>} 服务端虚拟路由管理新增后领域对象集合     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "批量新增服务端虚拟路由管理")
    @PostMapping("/batchStory")
    public Result<List<LazyNettyServerVirtualRoute>> batchStory(@RequestBody List<LazyNettyServerVirtualRouteStoryCommand> lazyNettyServerVirtualRouteStoryCommandList){
        return lazyNettyServerVirtualRouteApplication.batchStory(lazyNettyServerVirtualRouteStoryCommandList);
    }
    /**
     * describe 更新服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteUpdateCommand 更新服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRoute>} 服务端虚拟路由管理领域对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "更新服务端虚拟路由管理")
    @PutMapping("/updateOne")
    public Result<LazyNettyServerVirtualRoute> updateOne(@RequestBody LazyNettyServerVirtualRouteUpdateCommand lazyNettyServerVirtualRouteUpdateCommand){
        return lazyNettyServerVirtualRouteApplication.updateOne(lazyNettyServerVirtualRouteUpdateCommand);
    }
    /**
     * describe 查询单个服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteQueryOneCommand 查询单个服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRouteDTO>} 服务端虚拟路由管理DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "查询单个服务端虚拟路由管理")
    @GetMapping("/findOne")
    public Result<LazyNettyServerVirtualRouteDTO> findOne(@ModelAttribute LazyNettyServerVirtualRouteQueryOneCommand lazyNettyServerVirtualRouteQueryOneCommand){
        return lazyNettyServerVirtualRouteApplication.findOne(lazyNettyServerVirtualRouteQueryOneCommand);
    }
    /**
     * describe 查询多个服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteQueryListCommand 查询多个服务端虚拟路由管理     
     * @return {@link Result<List<LazyNettyServerVirtualRouteDTO>>} 服务端虚拟路由管理DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "查询多个服务端虚拟路由管理")
    @GetMapping("/findList")
    public Result<List<LazyNettyServerVirtualRouteDTO>> findList(@ModelAttribute LazyNettyServerVirtualRouteQueryListCommand lazyNettyServerVirtualRouteQueryListCommand){
        return lazyNettyServerVirtualRouteApplication.findList(lazyNettyServerVirtualRouteQueryListCommand);
    }
    /**
     * describe 分页查询多个服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteQueryListCommand 分页查询多个服务端虚拟路由管理     
     * @return {@link Result<LazyPage<LazyNettyServerVirtualRouteDTO>>} 分页服务端虚拟路由管理DTO对象     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "分页查询多个服务端虚拟路由管理")
    @GetMapping("/findPage")
    public Result<LazyPage<LazyNettyServerVirtualRouteDTO>> findPage(@Parameter(description ="分页大小") @RequestParam(defaultValue = "10", value = "size") int size,
                           @Parameter(description ="当前页数") @RequestParam(defaultValue = "1", value = "current") int current,@ModelAttribute LazyNettyServerVirtualRouteQueryListCommand lazyNettyServerVirtualRouteQueryListCommand){
        return lazyNettyServerVirtualRouteApplication.findPage(size,current,lazyNettyServerVirtualRouteQueryListCommand);
    }
    /**
     * describe 删除服务端虚拟路由管理
     *
     * @param lazyNettyServerVirtualRouteRemoveCommand 删除服务端虚拟路由管理     
     * @return {@link Result<LazyNettyServerVirtualRoute>} 服务端虚拟路由管理     
     
     * @author Jia wei Wu
     * @date 2025/05/06 05:00 下午
     **/

    @Operation(summary = "删除服务端虚拟路由管理")
    @DeleteMapping("/remove")
    public Result<LazyNettyServerVirtualRoute> remove(@ModelAttribute LazyNettyServerVirtualRouteRemoveCommand lazyNettyServerVirtualRouteRemoveCommand){
        return lazyNettyServerVirtualRouteApplication.remove(lazyNettyServerVirtualRouteRemoveCommand);
    }
}